@@ -34,7 +34,7 @@ def get_index_ids(es: Elasticsearch, index: str) -> list:
         ids = [document['_id'] for document in res['hits']['hits']]
         return ids
     else:
-        raise exception.NoExistIndexError('Index named ' + index + ' doesn\'t exist.')
+        raise exception.NonExistIndexError('Index named ' + index + ' doesn\'t exist.')
 
 
 def get_index_count(es: Elasticsearch, index: str) -> int:
@@ -45,6 +45,6 @@ def get_index_count(es: Elasticsearch, index: str) -> int:
     
         return len(res['hits']['hits'])
     else:
-        raise exception.NoExistIndexError('Index named ' + index + ' doesn\'t exist.')
+        raise exception.NonExistIndexError('Index named ' + index + ' doesn\'t exist.')
     
     
